# Crypto_APIs_2.0_SDK_Python
Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://cryptoapis.io](https://cryptoapis.io)

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/Crypto-APIs/Crypto_APIs_2.0_SDK_Python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/Crypto-APIs/Crypto_APIs_2.0_SDK_Python.git`)

Then import the package:
```python
import cryptoapis
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import cryptoapis
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import cryptoapis
from pprint import pprint
from cryptoapis.api import assets_api
from cryptoapis.model.feature_mainnets_not_allowed_for_plan import FeatureMainnetsNotAllowedForPlan
from cryptoapis.model.insufficient_credits import InsufficientCredits
from cryptoapis.model.invalid_api_key import InvalidApiKey
from cryptoapis.model.invalid_data import InvalidData
from cryptoapis.model.invalid_pagination import InvalidPagination
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
from cryptoapis.model.list_assets_details_response import ListAssetsDetailsResponse
from cryptoapis.model.request_limit_reached import RequestLimitReached
from cryptoapis.model.unexpected_server_error import UnexpectedServerError
from cryptoapis.model.unsupported_media_type import UnsupportedMediaType
# Defining the host is optional and defaults to https://rest.cryptoapis.io/v2
# See configuration.py for a list of all supported configuration parameters.
configuration = cryptoapis.Configuration(
    host = "https://rest.cryptoapis.io/v2"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKey
configuration.api_key['ApiKey'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKey'] = 'Bearer'


# Enter a context with an instance of the API client
with cryptoapis.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = assets_api.AssetsApi(api_client)
    context = "context_example" # str | In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user. (optional)
asset_type = "crypto" # str | Defines the type of the supported asset. This could be either \"crypto\" or \"fiat\". (optional)
limit = 50 # int | Defines how many items should be returned in the response per page basis. (optional) (default to 50)
offset = 10 # int | The starting index of the response items, i.e. where the response should start listing the returned items. (optional) (default to 0)

    try:
        # List Assets Details
        api_response = api_instance.list_assets_details(context=context, asset_type=asset_type, limit=limit, offset=offset)
        pprint(api_response)
    except cryptoapis.ApiException as e:
        print("Exception when calling AssetsApi->list_assets_details: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://rest.cryptoapis.io/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AssetsApi* | [**list_assets_details**](docs/AssetsApi.md#list_assets_details) | **GET** /market-data/assets/details | List Assets Details
*AutomaticCoinsForwardingApi* | [**create_automatic_coins_forwarding**](docs/AutomaticCoinsForwardingApi.md#create_automatic_coins_forwarding) | **POST** /blockchain-automations/{blockchain}/{network}/coins-forwarding/automations | Create Automatic Coins Forwarding
*AutomaticCoinsForwardingApi* | [**delete_automatic_coins_forwarding**](docs/AutomaticCoinsForwardingApi.md#delete_automatic_coins_forwarding) | **DELETE** /blockchain-automations/{blockchain}/{network}/coins-forwarding/automations/{referenceId} | Delete Automatic Coins Forwarding
*AutomaticCoinsForwardingApi* | [**list_coins_forwarding_automations**](docs/AutomaticCoinsForwardingApi.md#list_coins_forwarding_automations) | **GET** /blockchain-automations/{blockchain}/{network}/coins-forwarding/automations | List Coins Forwarding Automations
*AutomaticTokensForwardingApi* | [**add_tokens_to_existing_from_address**](docs/AutomaticTokensForwardingApi.md#add_tokens_to_existing_from_address) | **POST** /blockchain-automations/{blockchain}/{network}/tokens-forwarding/automations/add-token | Add Tokens To Existing fromAddress
*AutomaticTokensForwardingApi* | [**create_automatic_tokens_forwarding**](docs/AutomaticTokensForwardingApi.md#create_automatic_tokens_forwarding) | **POST** /blockchain-automations/{blockchain}/{network}/tokens-forwarding/automations | Create Automatic Tokens Forwarding
*AutomaticTokensForwardingApi* | [**delete_automatic_tokens_forwarding**](docs/AutomaticTokensForwardingApi.md#delete_automatic_tokens_forwarding) | **DELETE** /blockchain-automations/{blockchain}/{network}/tokens-forwarding/automations/{referenceId} | Delete Automatic Tokens Forwarding
*AutomaticTokensForwardingApi* | [**get_fee_address_details**](docs/AutomaticTokensForwardingApi.md#get_fee_address_details) | **GET** /blockchain-automations/{blockchain}/{network}/tokens-forwarding/fee-addresses | Get Fee Address Details
*AutomaticTokensForwardingApi* | [**list_tokens_forwarding_automations**](docs/AutomaticTokensForwardingApi.md#list_tokens_forwarding_automations) | **GET** /blockchain-automations/{blockchain}/{network}/tokens-forwarding/automations | List Tokens Forwarding Automations
*CreateSubscriptionsForApi* | [**mined_transaction**](docs/CreateSubscriptionsForApi.md#mined_transaction) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/transaction-mined | Mined transaction
*CreateSubscriptionsForApi* | [**new_block**](docs/CreateSubscriptionsForApi.md#new_block) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/block-mined | New Block
*CreateSubscriptionsForApi* | [**new_confirmed_coins_transactions**](docs/CreateSubscriptionsForApi.md#new_confirmed_coins_transactions) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-coins-transactions-confirmed | New confirmed coins transactions
*CreateSubscriptionsForApi* | [**new_confirmed_coins_transactions_and_each_confirmation**](docs/CreateSubscriptionsForApi.md#new_confirmed_coins_transactions_and_each_confirmation) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-coins-transactions-confirmed-each-confirmation | New confirmed coins transactions and each confirmation
*CreateSubscriptionsForApi* | [**new_confirmed_tokens_transactions**](docs/CreateSubscriptionsForApi.md#new_confirmed_tokens_transactions) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-tokens-transactions-confirmed | New confirmed tokens transactions
*CreateSubscriptionsForApi* | [**new_confirmed_tokens_transactions_and_each_confirmation**](docs/CreateSubscriptionsForApi.md#new_confirmed_tokens_transactions_and_each_confirmation) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-tokens-transactions-confirmed-each-confirmation | New confirmed tokens transactions and each confirmation
*CreateSubscriptionsForApi* | [**new_unconfirmed_coins_transactions**](docs/CreateSubscriptionsForApi.md#new_unconfirmed_coins_transactions) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-coins-transactions-unconfirmed | New unconfirmed coins transactions
*CreateSubscriptionsForApi* | [**new_unconfirmed_tokens_transactions**](docs/CreateSubscriptionsForApi.md#new_unconfirmed_tokens_transactions) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-tokens-transactions-unconfirmed | New unconfirmed tokens transactions
*ExchangeRatesApi* | [**get_exchange_rate_by_asset_symbols**](docs/ExchangeRatesApi.md#get_exchange_rate_by_asset_symbols) | **GET** /market-data/exchange-rates/by-symbols/{fromAssetSymbol}/{toAssetSymbol} | Get Exchange Rate By Asset Symbols
*ExchangeRatesApi* | [**get_exchange_rate_by_assets_ids**](docs/ExchangeRatesApi.md#get_exchange_rate_by_assets_ids) | **GET** /market-data/exchange-rates/by-asset-ids/{fromAssetId}/{toAssetId} | Get Exchange Rate By Assets IDs
*ManageSubscriptionsApi* | [**delete_blockchain_event_subscription**](docs/ManageSubscriptionsApi.md#delete_blockchain_event_subscription) | **DELETE** /blockchain-events/{blockchain}/{network}/subscriptions/{referenceId} | Delete Blockchain Event Subscription
*ManageSubscriptionsApi* | [**list_blockchain_events_subscriptions**](docs/ManageSubscriptionsApi.md#list_blockchain_events_subscriptions) | **GET** /blockchain-events/{blockchain}/{network}/subscriptions | List Blockchain Events Subscriptions
*MetadataApi* | [**list_supported_assets**](docs/MetadataApi.md#list_supported_assets) | **GET** /market-data/assets/supported | List Supported Assets
*OmniLayerApi* | [**get_omni_transaction_details_by_transaction_id__txid**](docs/OmniLayerApi.md#get_omni_transaction_details_by_transaction_id__txid) | **GET** /blockchain-data/{blockchain}/{network}/omni/transactions/{transactionId} | Get Omni Transaction Details By Transaction ID (Txid)
*OmniLayerApi* | [**get_unconfirmed_omni_transaction_by_transaction_id__txid**](docs/OmniLayerApi.md#get_unconfirmed_omni_transaction_by_transaction_id__txid) | **GET** /blockchain-data/{blockchain}/{network}/omni/transactions-unconfirmed/{transactionId} | Get Unconfirmed Omni Transaction By Transaction ID (Txid)
*OmniLayerApi* | [**list_omni_tokens_by_address**](docs/OmniLayerApi.md#list_omni_tokens_by_address) | **GET** /blockchain-data/{blockchain}/{network}/omni/addresses/{address} | List Omni Tokens By Address
*OmniLayerApi* | [**list_omni_transactions_by_address**](docs/OmniLayerApi.md#list_omni_transactions_by_address) | **GET** /blockchain-data/{blockchain}/{network}/omni/addresses/{address}/transactions | List Omni Transactions By Address
*OmniLayerApi* | [**list_omni_transactions_by_block_hash**](docs/OmniLayerApi.md#list_omni_transactions_by_block_hash) | **GET** /blockchain-data/{blockchain}/{network}/omni/blocks/hash/{blockHash}/transactions | List Omni Transactions By Block Hash
*OmniLayerApi* | [**list_omni_transactions_by_block_height**](docs/OmniLayerApi.md#list_omni_transactions_by_block_height) | **GET** /blockchain-data/{blockchain}/{network}/omni/blocks/height/{blockHeight}/transactions | List Omni Transactions By Block Height
*OmniLayerApi* | [**list_unconfirmed_omni_transactions_by_address**](docs/OmniLayerApi.md#list_unconfirmed_omni_transactions_by_address) | **GET** /blockchain-data/{blockchain}/{network}/omni/address-transactions-unconfirmed/{address} | List Unconfirmed Omni Transactions By Address
*OmniLayerApi* | [**list_unconfirmed_omni_transactions_by_property_id**](docs/OmniLayerApi.md#list_unconfirmed_omni_transactions_by_property_id) | **GET** /blockchain-data/{blockchain}/{network}/omni/properties/{propertyId}/transactions | List Unconfirmed Omni Transactions By Property ID
*TokensApi* | [**list_tokens_by_address**](docs/TokensApi.md#list_tokens_by_address) | **GET** /blockchain-data/{blockchain}/{network}/addresses/{address}/tokens | List Tokens By Address
*TokensApi* | [**list_tokens_transfers_by_address**](docs/TokensApi.md#list_tokens_transfers_by_address) | **GET** /blockchain-data/{blockchain}/{network}/addresses/{address}/tokens-transfers | List Tokens Transfers By Address
*TokensApi* | [**list_tokens_transfers_by_transaction_hash**](docs/TokensApi.md#list_tokens_transfers_by_transaction_hash) | **GET** /blockchain-data/{blockchain}/{network}/transactions/{transactionHash}/tokens-transfers | List Tokens Transfers By Transaction Hash
*UTXOBasedApi* | [**get_hd_wallet__x_pub_y_pub_z_pub_details**](docs/UTXOBasedApi.md#get_hd_wallet__x_pub_y_pub_z_pub_details) | **GET** /blockchain-data/{blockchain}/{network}/hd/{extendedPublicKey}/details | Get HD Wallet (xPub, yPub, zPub) Details
*UTXOBasedApi* | [**list_hd_wallet__x_pub_y_pub_z_pub_transactions**](docs/UTXOBasedApi.md#list_hd_wallet__x_pub_y_pub_z_pub_transactions) | **GET** /blockchain-data/{blockchain}/{network}/hd/{extendedPublicKey}/transactions | List HD Wallet (xPub, yPub, zPub) Transactions
*UTXOBasedApi* | [**sync_hd_wallet__x_pub_y_pub_z_pub**](docs/UTXOBasedApi.md#sync_hd_wallet__x_pub_y_pub_z_pub) | **POST** /blockchain-data/{blockchain}/{network}/hd/sync | Sync HD Wallet (xPub, yPub, zPub)
*UnifiedEndpointsApi* | [**get_address_details**](docs/UnifiedEndpointsApi.md#get_address_details) | **GET** /blockchain-data/{blockchain}/{network}/addresses/{address} | Get Address Details
*UnifiedEndpointsApi* | [**get_block_details_by_block_hash**](docs/UnifiedEndpointsApi.md#get_block_details_by_block_hash) | **GET** /blockchain-data/{blockchain}/{network}/blocks/hash/{blockHash} | Get Block Details By Block Hash
*UnifiedEndpointsApi* | [**get_block_details_by_block_height**](docs/UnifiedEndpointsApi.md#get_block_details_by_block_height) | **GET** /blockchain-data/{blockchain}/{network}/blocks/height/{height} | Get Block Details By Block Height
*UnifiedEndpointsApi* | [**get_fee_recommendations**](docs/UnifiedEndpointsApi.md#get_fee_recommendations) | **GET** /blockchain-data/{blockchain}/{network}/mempool/fees | Get Fee Recommendations
*UnifiedEndpointsApi* | [**get_latest_mined_block**](docs/UnifiedEndpointsApi.md#get_latest_mined_block) | **GET** /blockchain-data/{blockchain}/{network}/blocks/last | Get Latest Mined Block
*UnifiedEndpointsApi* | [**get_transaction_details_by_transaction_id**](docs/UnifiedEndpointsApi.md#get_transaction_details_by_transaction_id) | **GET** /blockchain-data/{blockchain}/{network}/transactions/{transactionId} | Get Transaction Details By Transaction ID
*UnifiedEndpointsApi* | [**list_transactions_by_address**](docs/UnifiedEndpointsApi.md#list_transactions_by_address) | **GET** /blockchain-data/{blockchain}/{network}/addresses/{address}/transactions | List Transactions By Address
*UnifiedEndpointsApi* | [**list_transactions_by_block_hash**](docs/UnifiedEndpointsApi.md#list_transactions_by_block_hash) | **GET** /blockchain-data/{blockchain}/{network}/blocks/hash/{blockHash}/transactions | List Transactions by Block Hash
*UnifiedEndpointsApi* | [**list_transactions_by_block_height**](docs/UnifiedEndpointsApi.md#list_transactions_by_block_height) | **GET** /blockchain-data/{blockchain}/{network}/blocks/height/{height}/transactions | List Transactions by Block Height
*ValidatingApi* | [**validate_address**](docs/ValidatingApi.md#validate_address) | **POST** /blockchain-tools/{blockchain}/{network}/addresses/validate | Validate Address
*XRPRippleApi* | [**get_latest_mined_xrp__ripple_block**](docs/XRPRippleApi.md#get_latest_mined_xrp__ripple_block) | **GET** /blockchain-data/xrp/{network}/blocks/last | Get Latest Mined XRP (Ripple) Block
*XRPRippleApi* | [**get_xrp__ripple_address_details**](docs/XRPRippleApi.md#get_xrp__ripple_address_details) | **GET** /blockchain-data/xrp/{network}/addresses/{address} | Get XRP (Ripple) Address Details
*XRPRippleApi* | [**get_xrp__ripple_block_details_by_block_hash**](docs/XRPRippleApi.md#get_xrp__ripple_block_details_by_block_hash) | **GET** /blockchain-data/xrp/{network}/blocks/hash/{blockHash} | Get XRP (Ripple) Block Details By Block Hash
*XRPRippleApi* | [**get_xrp__ripple_block_details_by_block_height**](docs/XRPRippleApi.md#get_xrp__ripple_block_details_by_block_height) | **GET** /blockchain-data/xrp/{network}/blocks/height/{height} | Get XRP (Ripple) Block Details By Block Height
*XRPRippleApi* | [**get_xrp__ripple_transaction_details_by_transaction_id**](docs/XRPRippleApi.md#get_xrp__ripple_transaction_details_by_transaction_id) | **GET** /blockchain-data/xrp/{network}/transactions/{transactionHash} | Get XRP (Ripple) Transaction Details By Transaction ID
*XRPRippleApi* | [**list_xrp__ripple_transactions_by_address**](docs/XRPRippleApi.md#list_xrp__ripple_transactions_by_address) | **GET** /blockchain-data/xrp/{network}/addresses/{address}/transactions | List XRP (Ripple) Transactions by Address
*XRPRippleApi* | [**list_xrp__ripple_transactions_by_block_hash**](docs/XRPRippleApi.md#list_xrp__ripple_transactions_by_block_hash) | **GET** /blockchain-data/xrp/{network}/blocks/hash/{blockHash}/transactions | List XRP (Ripple) Transactions By Block Hash
*DefaultApi* | [**get_contract_details_by_address**](docs/DefaultApi.md#get_contract_details_by_address) | **GET** /blockchain-data/{blockchain}/{network}/addresses/{contractAddress}/contract | Get Contract Details by Address


## Documentation For Models

 - [AddTokensToExistingFromAddressRequestBody](docs/AddTokensToExistingFromAddressRequestBody.md)
 - [AddTokensToExistingFromAddressRequestBodyData](docs/AddTokensToExistingFromAddressRequestBodyData.md)
 - [AddTokensToExistingFromAddressRequestBodyDataItem](docs/AddTokensToExistingFromAddressRequestBodyDataItem.md)
 - [AddTokensToExistingFromAddressRequestBodyTokenData](docs/AddTokensToExistingFromAddressRequestBodyTokenData.md)
 - [AddTokensToExistingFromAddressRequestBodyTokenDataBitcoinOmniToken](docs/AddTokensToExistingFromAddressRequestBodyTokenDataBitcoinOmniToken.md)
 - [AddTokensToExistingFromAddressRequestBodyTokenDataEthereumErc20Token](docs/AddTokensToExistingFromAddressRequestBodyTokenDataEthereumErc20Token.md)
 - [AddTokensToExistingFromAddressResponse](docs/AddTokensToExistingFromAddressResponse.md)
 - [AddTokensToExistingFromAddressResponseData](docs/AddTokensToExistingFromAddressResponseData.md)
 - [AddTokensToExistingFromAddressResponseItem](docs/AddTokensToExistingFromAddressResponseItem.md)
 - [AddTokensToExistingFromAddressResponseItemTokenData](docs/AddTokensToExistingFromAddressResponseItemTokenData.md)
 - [AddTokensToExistingFromAddressResponseItemTokenDataBitcoinOmniToken](docs/AddTokensToExistingFromAddressResponseItemTokenDataBitcoinOmniToken.md)
 - [AddTokensToExistingFromAddressResponseItemTokenDataEthereumErc20Token](docs/AddTokensToExistingFromAddressResponseItemTokenDataEthereumErc20Token.md)
 - [AddressCoinsTransactionConfirmed](docs/AddressCoinsTransactionConfirmed.md)
 - [AddressCoinsTransactionConfirmedData](docs/AddressCoinsTransactionConfirmedData.md)
 - [AddressCoinsTransactionConfirmedDataItem](docs/AddressCoinsTransactionConfirmedDataItem.md)
 - [AddressCoinsTransactionConfirmedDataItemMinedInBlock](docs/AddressCoinsTransactionConfirmedDataItemMinedInBlock.md)
 - [AddressCoinsTransactionConfirmedEachConfirmation](docs/AddressCoinsTransactionConfirmedEachConfirmation.md)
 - [AddressCoinsTransactionConfirmedEachConfirmationData](docs/AddressCoinsTransactionConfirmedEachConfirmationData.md)
 - [AddressCoinsTransactionConfirmedEachConfirmationDataItem](docs/AddressCoinsTransactionConfirmedEachConfirmationDataItem.md)
 - [AddressCoinsTransactionConfirmedEachConfirmationDataItemMinedInBlock](docs/AddressCoinsTransactionConfirmedEachConfirmationDataItemMinedInBlock.md)
 - [AddressCoinsTransactionUnconfirmed](docs/AddressCoinsTransactionUnconfirmed.md)
 - [AddressCoinsTransactionUnconfirmedData](docs/AddressCoinsTransactionUnconfirmedData.md)
 - [AddressCoinsTransactionUnconfirmedDataItem](docs/AddressCoinsTransactionUnconfirmedDataItem.md)
 - [AddressTokensTransactionConfirmed](docs/AddressTokensTransactionConfirmed.md)
 - [AddressTokensTransactionConfirmedData](docs/AddressTokensTransactionConfirmedData.md)
 - [AddressTokensTransactionConfirmedDataItem](docs/AddressTokensTransactionConfirmedDataItem.md)
 - [AddressTokensTransactionConfirmedDataItemMinedInBlock](docs/AddressTokensTransactionConfirmedDataItemMinedInBlock.md)
 - [AddressTokensTransactionConfirmedEachConfirmation](docs/AddressTokensTransactionConfirmedEachConfirmation.md)
 - [AddressTokensTransactionConfirmedEachConfirmationData](docs/AddressTokensTransactionConfirmedEachConfirmationData.md)
 - [AddressTokensTransactionConfirmedEachConfirmationDataItem](docs/AddressTokensTransactionConfirmedEachConfirmationDataItem.md)
 - [AddressTokensTransactionConfirmedEachConfirmationDataItemMinedInBlock](docs/AddressTokensTransactionConfirmedEachConfirmationDataItemMinedInBlock.md)
 - [AddressTokensTransactionConfirmedEachConfirmationEthereumerc20token](docs/AddressTokensTransactionConfirmedEachConfirmationEthereumerc20token.md)
 - [AddressTokensTransactionConfirmedEachConfirmationEthereumerc721token](docs/AddressTokensTransactionConfirmedEachConfirmationEthereumerc721token.md)
 - [AddressTokensTransactionConfirmedEachConfirmationOmnilayertoken](docs/AddressTokensTransactionConfirmedEachConfirmationOmnilayertoken.md)
 - [AddressTokensTransactionConfirmedEachConfirmationToken](docs/AddressTokensTransactionConfirmedEachConfirmationToken.md)
 - [AddressTokensTransactionConfirmedEthereumerc20token](docs/AddressTokensTransactionConfirmedEthereumerc20token.md)
 - [AddressTokensTransactionConfirmedEthereumerc721token](docs/AddressTokensTransactionConfirmedEthereumerc721token.md)
 - [AddressTokensTransactionConfirmedOmnilayertoken](docs/AddressTokensTransactionConfirmedOmnilayertoken.md)
 - [AddressTokensTransactionConfirmedToken](docs/AddressTokensTransactionConfirmedToken.md)
 - [AddressTokensTransactionUnconfirmed](docs/AddressTokensTransactionUnconfirmed.md)
 - [AddressTokensTransactionUnconfirmedData](docs/AddressTokensTransactionUnconfirmedData.md)
 - [AddressTokensTransactionUnconfirmedDataItem](docs/AddressTokensTransactionUnconfirmedDataItem.md)
 - [AddressTokensTransactionUnconfirmedEthereumerc20token](docs/AddressTokensTransactionUnconfirmedEthereumerc20token.md)
 - [AddressTokensTransactionUnconfirmedEthereumerc721token](docs/AddressTokensTransactionUnconfirmedEthereumerc721token.md)
 - [AddressTokensTransactionUnconfirmedOmnilayertoken](docs/AddressTokensTransactionUnconfirmedOmnilayertoken.md)
 - [AddressTokensTransactionUnconfirmedToken](docs/AddressTokensTransactionUnconfirmedToken.md)
 - [AlreadyExists](docs/AlreadyExists.md)
 - [AlreadyExistsError](docs/AlreadyExistsError.md)
 - [BannedIpAddress](docs/BannedIpAddress.md)
 - [BannedIpAddressError](docs/BannedIpAddressError.md)
 - [BannedIpAddressErrorDetails](docs/BannedIpAddressErrorDetails.md)
 - [BlockMined](docs/BlockMined.md)
 - [BlockMinedData](docs/BlockMinedData.md)
 - [BlockMinedDataItem](docs/BlockMinedDataItem.md)
 - [BlockchainDataBlockNotFound](docs/BlockchainDataBlockNotFound.md)
 - [BlockchainDataBlockNotFoundError](docs/BlockchainDataBlockNotFoundError.md)
 - [BlockchainDataTransactionNotFound](docs/BlockchainDataTransactionNotFound.md)
 - [BlockchainDataTransactionNotFoundError](docs/BlockchainDataTransactionNotFoundError.md)
 - [BlockchainEventsCallbacksLimitReached](docs/BlockchainEventsCallbacksLimitReached.md)
 - [BlockchainEventsCallbacksLimitReachedError](docs/BlockchainEventsCallbacksLimitReachedError.md)
 - [CoinsForwardingAutomationsLimitReached](docs/CoinsForwardingAutomationsLimitReached.md)
 - [CoinsForwardingAutomationsLimitReachedError](docs/CoinsForwardingAutomationsLimitReachedError.md)
 - [CoinsForwardingFail](docs/CoinsForwardingFail.md)
 - [CoinsForwardingFailData](docs/CoinsForwardingFailData.md)
 - [CoinsForwardingFailDataItem](docs/CoinsForwardingFailDataItem.md)
 - [CoinsForwardingSuccess](docs/CoinsForwardingSuccess.md)
 - [CoinsForwardingSuccessData](docs/CoinsForwardingSuccessData.md)
 - [CoinsForwardingSuccessDataItem](docs/CoinsForwardingSuccessDataItem.md)
 - [CouldNotCalculateRateForPair](docs/CouldNotCalculateRateForPair.md)
 - [CouldNotCalculateRateForPairError](docs/CouldNotCalculateRateForPairError.md)
 - [CreateAutomaticCoinsForwardingRequestBody](docs/CreateAutomaticCoinsForwardingRequestBody.md)
 - [CreateAutomaticCoinsForwardingRequestBodyData](docs/CreateAutomaticCoinsForwardingRequestBodyData.md)
 - [CreateAutomaticCoinsForwardingRequestBodyDataItem](docs/CreateAutomaticCoinsForwardingRequestBodyDataItem.md)
 - [CreateAutomaticCoinsForwardingResponse](docs/CreateAutomaticCoinsForwardingResponse.md)
 - [CreateAutomaticCoinsForwardingResponseData](docs/CreateAutomaticCoinsForwardingResponseData.md)
 - [CreateAutomaticCoinsForwardingResponseItem](docs/CreateAutomaticCoinsForwardingResponseItem.md)
 - [CreateAutomaticTokensForwardingRequestBody](docs/CreateAutomaticTokensForwardingRequestBody.md)
 - [CreateAutomaticTokensForwardingRequestBodyData](docs/CreateAutomaticTokensForwardingRequestBodyData.md)
 - [CreateAutomaticTokensForwardingRequestBodyDataItem](docs/CreateAutomaticTokensForwardingRequestBodyDataItem.md)
 - [CreateAutomaticTokensForwardingRequestBodyTokenData](docs/CreateAutomaticTokensForwardingRequestBodyTokenData.md)
 - [CreateAutomaticTokensForwardingRequestBodyTokenDataBitcoinOmniToken](docs/CreateAutomaticTokensForwardingRequestBodyTokenDataBitcoinOmniToken.md)
 - [CreateAutomaticTokensForwardingRequestBodyTokenDataEthereumToken](docs/CreateAutomaticTokensForwardingRequestBodyTokenDataEthereumToken.md)
 - [CreateAutomaticTokensForwardingResponse](docs/CreateAutomaticTokensForwardingResponse.md)
 - [CreateAutomaticTokensForwardingResponseData](docs/CreateAutomaticTokensForwardingResponseData.md)
 - [CreateAutomaticTokensForwardingResponseItem](docs/CreateAutomaticTokensForwardingResponseItem.md)
 - [CreateAutomaticTokensForwardingResponseItemTokenData](docs/CreateAutomaticTokensForwardingResponseItemTokenData.md)
 - [CreateAutomaticTokensForwardingResponseItemTokenDataBitcoinOmniToken](docs/CreateAutomaticTokensForwardingResponseItemTokenDataBitcoinOmniToken.md)
 - [CreateAutomaticTokensForwardingResponseItemTokenDataEthereumToken](docs/CreateAutomaticTokensForwardingResponseItemTokenDataEthereumToken.md)
 - [DeleteAutomaticCoinsForwardingResponse](docs/DeleteAutomaticCoinsForwardingResponse.md)
 - [DeleteAutomaticCoinsForwardingResponseData](docs/DeleteAutomaticCoinsForwardingResponseData.md)
 - [DeleteAutomaticCoinsForwardingResponseItem](docs/DeleteAutomaticCoinsForwardingResponseItem.md)
 - [DeleteAutomaticTokensForwardingResponse](docs/DeleteAutomaticTokensForwardingResponse.md)
 - [DeleteAutomaticTokensForwardingResponseData](docs/DeleteAutomaticTokensForwardingResponseData.md)
 - [DeleteAutomaticTokensForwardingResponseItem](docs/DeleteAutomaticTokensForwardingResponseItem.md)
 - [DeleteAutomaticTokensForwardingResponseItemTokenData](docs/DeleteAutomaticTokensForwardingResponseItemTokenData.md)
 - [DeleteAutomaticTokensForwardingResponseItemTokenDataBitcoinOmniToken](docs/DeleteAutomaticTokensForwardingResponseItemTokenDataBitcoinOmniToken.md)
 - [DeleteAutomaticTokensForwardingResponseItemTokenDataEthereumToken](docs/DeleteAutomaticTokensForwardingResponseItemTokenDataEthereumToken.md)
 - [DeleteBlockchainEventSubscriptionResponse](docs/DeleteBlockchainEventSubscriptionResponse.md)
 - [DeleteBlockchainEventSubscriptionResponseData](docs/DeleteBlockchainEventSubscriptionResponseData.md)
 - [DeleteBlockchainEventSubscriptionResponseItem](docs/DeleteBlockchainEventSubscriptionResponseItem.md)
 - [EndpointNotAllowedForApiKey](docs/EndpointNotAllowedForApiKey.md)
 - [EndpointNotAllowedForApiKeyError](docs/EndpointNotAllowedForApiKeyError.md)
 - [EndpointNotAllowedForPlan](docs/EndpointNotAllowedForPlan.md)
 - [EndpointNotAllowedForPlanError](docs/EndpointNotAllowedForPlanError.md)
 - [FeatureMainnetsNotAllowedForPlan](docs/FeatureMainnetsNotAllowedForPlan.md)
 - [FeatureMainnetsNotAllowedForPlanError](docs/FeatureMainnetsNotAllowedForPlanError.md)
 - [GetAddressDetailsResponse](docs/GetAddressDetailsResponse.md)
 - [GetAddressDetailsResponseData](docs/GetAddressDetailsResponseData.md)
 - [GetAddressDetailsResponseItem](docs/GetAddressDetailsResponseItem.md)
 - [GetAddressDetailsResponseItemConfirmedBalance](docs/GetAddressDetailsResponseItemConfirmedBalance.md)
 - [GetAddressDetailsResponseItemTotalReceived](docs/GetAddressDetailsResponseItemTotalReceived.md)
 - [GetAddressDetailsResponseItemTotalSpent](docs/GetAddressDetailsResponseItemTotalSpent.md)
 - [GetBlockDetailsByBlockHashResponse](docs/GetBlockDetailsByBlockHashResponse.md)
 - [GetBlockDetailsByBlockHashResponseData](docs/GetBlockDetailsByBlockHashResponseData.md)
 - [GetBlockDetailsByBlockHashResponseItem](docs/GetBlockDetailsByBlockHashResponseItem.md)
 - [GetBlockDetailsByBlockHashResponseItemBlockchainSpecific](docs/GetBlockDetailsByBlockHashResponseItemBlockchainSpecific.md)
 - [GetBlockDetailsByBlockHashResponseItemBlockchainSpecificBitcoin](docs/GetBlockDetailsByBlockHashResponseItemBlockchainSpecificBitcoin.md)
 - [GetBlockDetailsByBlockHashResponseItemBlockchainSpecificBitcoinCash](docs/GetBlockDetailsByBlockHashResponseItemBlockchainSpecificBitcoinCash.md)
 - [GetBlockDetailsByBlockHashResponseItemBlockchainSpecificDash](docs/GetBlockDetailsByBlockHashResponseItemBlockchainSpecificDash.md)
 - [GetBlockDetailsByBlockHashResponseItemBlockchainSpecificDogecoin](docs/GetBlockDetailsByBlockHashResponseItemBlockchainSpecificDogecoin.md)
 - [GetBlockDetailsByBlockHashResponseItemBlockchainSpecificEthereum](docs/GetBlockDetailsByBlockHashResponseItemBlockchainSpecificEthereum.md)
 - [GetBlockDetailsByBlockHashResponseItemBlockchainSpecificEthereumClassic](docs/GetBlockDetailsByBlockHashResponseItemBlockchainSpecificEthereumClassic.md)
 - [GetBlockDetailsByBlockHashResponseItemBlockchainSpecificLitecoin](docs/GetBlockDetailsByBlockHashResponseItemBlockchainSpecificLitecoin.md)
 - [GetBlockDetailsByBlockHeightResponse](docs/GetBlockDetailsByBlockHeightResponse.md)
 - [GetBlockDetailsByBlockHeightResponseData](docs/GetBlockDetailsByBlockHeightResponseData.md)
 - [GetBlockDetailsByBlockHeightResponseItem](docs/GetBlockDetailsByBlockHeightResponseItem.md)
 - [GetBlockDetailsByBlockHeightResponseItemBlockchainSpecific](docs/GetBlockDetailsByBlockHeightResponseItemBlockchainSpecific.md)
 - [GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificBitcoin](docs/GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificBitcoin.md)
 - [GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificBitcoinCash](docs/GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificBitcoinCash.md)
 - [GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificDash](docs/GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificDash.md)
 - [GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificDogecoin](docs/GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificDogecoin.md)
 - [GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificEthereum](docs/GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificEthereum.md)
 - [GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificEthereumClassic](docs/GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificEthereumClassic.md)
 - [GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificLitecoin](docs/GetBlockDetailsByBlockHeightResponseItemBlockchainSpecificLitecoin.md)
 - [GetContractDetailsByAddressResponse](docs/GetContractDetailsByAddressResponse.md)
 - [GetContractDetailsByAddressResponseData](docs/GetContractDetailsByAddressResponseData.md)
 - [GetContractDetailsByAddressResponseItem](docs/GetContractDetailsByAddressResponseItem.md)
 - [GetExchangeRateByAssetSymbolsResponse](docs/GetExchangeRateByAssetSymbolsResponse.md)
 - [GetExchangeRateByAssetSymbolsResponseData](docs/GetExchangeRateByAssetSymbolsResponseData.md)
 - [GetExchangeRateByAssetSymbolsResponseItem](docs/GetExchangeRateByAssetSymbolsResponseItem.md)
 - [GetExchangeRateByAssetsIDsResponse](docs/GetExchangeRateByAssetsIDsResponse.md)
 - [GetExchangeRateByAssetsIDsResponseData](docs/GetExchangeRateByAssetsIDsResponseData.md)
 - [GetExchangeRateByAssetsIDsResponseItem](docs/GetExchangeRateByAssetsIDsResponseItem.md)
 - [GetFeeAddressDetailsResponse](docs/GetFeeAddressDetailsResponse.md)
 - [GetFeeAddressDetailsResponseData](docs/GetFeeAddressDetailsResponseData.md)
 - [GetFeeAddressDetailsResponseItem](docs/GetFeeAddressDetailsResponseItem.md)
 - [GetFeeAddressDetailsResponseItemBalance](docs/GetFeeAddressDetailsResponseItemBalance.md)
 - [GetFeeRecommendationsResponse](docs/GetFeeRecommendationsResponse.md)
 - [GetFeeRecommendationsResponseData](docs/GetFeeRecommendationsResponseData.md)
 - [GetFeeRecommendationsResponseItem](docs/GetFeeRecommendationsResponseItem.md)
 - [GetHDWalletxPubYPubZPubDetailsResponse](docs/GetHDWalletxPubYPubZPubDetailsResponse.md)
 - [GetHDWalletxPubYPubZPubDetailsResponseData](docs/GetHDWalletxPubYPubZPubDetailsResponseData.md)
 - [GetHDWalletxPubYPubZPubDetailsResponseItem](docs/GetHDWalletxPubYPubZPubDetailsResponseItem.md)
 - [GetLatestMinedBlockResponse](docs/GetLatestMinedBlockResponse.md)
 - [GetLatestMinedBlockResponseData](docs/GetLatestMinedBlockResponseData.md)
 - [GetLatestMinedBlockResponseItem](docs/GetLatestMinedBlockResponseItem.md)
 - [GetLatestMinedBlockResponseItemBlockchainSpecific](docs/GetLatestMinedBlockResponseItemBlockchainSpecific.md)
 - [GetLatestMinedBlockResponseItemBlockchainSpecificBitcoin](docs/GetLatestMinedBlockResponseItemBlockchainSpecificBitcoin.md)
 - [GetLatestMinedBlockResponseItemBlockchainSpecificBitcoinCash](docs/GetLatestMinedBlockResponseItemBlockchainSpecificBitcoinCash.md)
 - [GetLatestMinedBlockResponseItemBlockchainSpecificDash](docs/GetLatestMinedBlockResponseItemBlockchainSpecificDash.md)
 - [GetLatestMinedBlockResponseItemBlockchainSpecificDogecoin](docs/GetLatestMinedBlockResponseItemBlockchainSpecificDogecoin.md)
 - [GetLatestMinedBlockResponseItemBlockchainSpecificEthereum](docs/GetLatestMinedBlockResponseItemBlockchainSpecificEthereum.md)
 - [GetLatestMinedBlockResponseItemBlockchainSpecificEthereumClassic](docs/GetLatestMinedBlockResponseItemBlockchainSpecificEthereumClassic.md)
 - [GetLatestMinedBlockResponseItemBlockchainSpecificLitecoin](docs/GetLatestMinedBlockResponseItemBlockchainSpecificLitecoin.md)
 - [GetLatestMinedXRPRippleBlockResponse](docs/GetLatestMinedXRPRippleBlockResponse.md)
 - [GetLatestMinedXRPRippleBlockResponseData](docs/GetLatestMinedXRPRippleBlockResponseData.md)
 - [GetLatestMinedXRPRippleBlockResponseItem](docs/GetLatestMinedXRPRippleBlockResponseItem.md)
 - [GetLatestMinedXRPRippleBlockResponseItemTotalCoins](docs/GetLatestMinedXRPRippleBlockResponseItemTotalCoins.md)
 - [GetLatestMinedXRPRippleBlockResponseItemTotalFees](docs/GetLatestMinedXRPRippleBlockResponseItemTotalFees.md)
 - [GetOmniTransactionDetailsByTransactionIDTxidResponse](docs/GetOmniTransactionDetailsByTransactionIDTxidResponse.md)
 - [GetOmniTransactionDetailsByTransactionIDTxidResponseData](docs/GetOmniTransactionDetailsByTransactionIDTxidResponseData.md)
 - [GetOmniTransactionDetailsByTransactionIDTxidResponseItem](docs/GetOmniTransactionDetailsByTransactionIDTxidResponseItem.md)
 - [GetOmniTransactionDetailsByTransactionIDTxidResponseItemSenders](docs/GetOmniTransactionDetailsByTransactionIDTxidResponseItemSenders.md)
 - [GetTransactionDetailsByTransactionIDResponse](docs/GetTransactionDetailsByTransactionIDResponse.md)
 - [GetTransactionDetailsByTransactionIDResponseData](docs/GetTransactionDetailsByTransactionIDResponseData.md)
 - [GetTransactionDetailsByTransactionIDResponseItem](docs/GetTransactionDetailsByTransactionIDResponseItem.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecific](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecific.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoin](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoin.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinCash](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinCash.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinCashScriptPubKey](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinCashScriptPubKey.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinCashVin](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinCashVin.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinCashVout](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinCashVout.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinScriptPubKey](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinScriptPubKey.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinScriptSig](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinScriptSig.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinVin](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinVin.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinVout](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificBitcoinVout.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDash](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDash.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDashScriptPubKey](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDashScriptPubKey.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDashScriptSig](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDashScriptSig.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDashVin](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDashVin.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDashVout](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDashVout.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDogecoin](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDogecoin.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDogecoinScriptPubKey](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDogecoinScriptPubKey.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDogecoinScriptSig](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDogecoinScriptSig.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDogecoinVin](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDogecoinVin.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDogecoinVout](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificDogecoinVout.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificEthereum](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificEthereum.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificEthereumClassic](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificEthereumClassic.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificEthereumClassicGasPrice](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificEthereumClassicGasPrice.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificEthereumGasPrice](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificEthereumGasPrice.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificLitecoin](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificLitecoin.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificLitecoinScriptPubKey](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificLitecoinScriptPubKey.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificLitecoinScriptSig](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificLitecoinScriptSig.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificLitecoinVin](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificLitecoinVin.md)
 - [GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificLitecoinVout](docs/GetTransactionDetailsByTransactionIDResponseItemBlockchainSpecificLitecoinVout.md)
 - [GetTransactionDetailsByTransactionIDResponseItemFee](docs/GetTransactionDetailsByTransactionIDResponseItemFee.md)
 - [GetTransactionDetailsByTransactionIDResponseItemRecipients](docs/GetTransactionDetailsByTransactionIDResponseItemRecipients.md)
 - [GetTransactionDetailsByTransactionIDResponseItemSenders](docs/GetTransactionDetailsByTransactionIDResponseItemSenders.md)
 - [GetUnconfirmedOmniTransactionByTransactionIDTxidResponse](docs/GetUnconfirmedOmniTransactionByTransactionIDTxidResponse.md)
 - [GetUnconfirmedOmniTransactionByTransactionIDTxidResponseData](docs/GetUnconfirmedOmniTransactionByTransactionIDTxidResponseData.md)
 - [GetUnconfirmedOmniTransactionByTransactionIDTxidResponseItem](docs/GetUnconfirmedOmniTransactionByTransactionIDTxidResponseItem.md)
 - [GetUnconfirmedOmniTransactionByTransactionIDTxidResponseItemRecipients](docs/GetUnconfirmedOmniTransactionByTransactionIDTxidResponseItemRecipients.md)
 - [GetUnconfirmedOmniTransactionByTransactionIDTxidResponseItemSenders](docs/GetUnconfirmedOmniTransactionByTransactionIDTxidResponseItemSenders.md)
 - [GetXRPRippleAddressDetailsResponse](docs/GetXRPRippleAddressDetailsResponse.md)
 - [GetXRPRippleAddressDetailsResponseData](docs/GetXRPRippleAddressDetailsResponseData.md)
 - [GetXRPRippleAddressDetailsResponseItem](docs/GetXRPRippleAddressDetailsResponseItem.md)
 - [GetXRPRippleAddressDetailsResponseItemBalance](docs/GetXRPRippleAddressDetailsResponseItemBalance.md)
 - [GetXRPRippleBlockDetailsByBlockHashResponse](docs/GetXRPRippleBlockDetailsByBlockHashResponse.md)
 - [GetXRPRippleBlockDetailsByBlockHashResponseData](docs/GetXRPRippleBlockDetailsByBlockHashResponseData.md)
 - [GetXRPRippleBlockDetailsByBlockHashResponseItem](docs/GetXRPRippleBlockDetailsByBlockHashResponseItem.md)
 - [GetXRPRippleBlockDetailsByBlockHashResponseItemTotalCoins](docs/GetXRPRippleBlockDetailsByBlockHashResponseItemTotalCoins.md)
 - [GetXRPRippleBlockDetailsByBlockHeightResponse](docs/GetXRPRippleBlockDetailsByBlockHeightResponse.md)
 - [GetXRPRippleBlockDetailsByBlockHeightResponseData](docs/GetXRPRippleBlockDetailsByBlockHeightResponseData.md)
 - [GetXRPRippleBlockDetailsByBlockHeightResponseItem](docs/GetXRPRippleBlockDetailsByBlockHeightResponseItem.md)
 - [GetXRPRippleBlockDetailsByBlockHeightResponseItemTotalCoins](docs/GetXRPRippleBlockDetailsByBlockHeightResponseItemTotalCoins.md)
 - [GetXRPRippleBlockDetailsByBlockHeightResponseItemTotalFees](docs/GetXRPRippleBlockDetailsByBlockHeightResponseItemTotalFees.md)
 - [GetXRPRippleTransactionDetailsByTransactionIDResponse](docs/GetXRPRippleTransactionDetailsByTransactionIDResponse.md)
 - [GetXRPRippleTransactionDetailsByTransactionIDResponseData](docs/GetXRPRippleTransactionDetailsByTransactionIDResponseData.md)
 - [GetXRPRippleTransactionDetailsByTransactionIDResponseItem](docs/GetXRPRippleTransactionDetailsByTransactionIDResponseItem.md)
 - [GetXRPRippleTransactionDetailsByTransactionIDResponseItemFee](docs/GetXRPRippleTransactionDetailsByTransactionIDResponseItemFee.md)
 - [GetXRPRippleTransactionDetailsByTransactionIDResponseItemOffer](docs/GetXRPRippleTransactionDetailsByTransactionIDResponseItemOffer.md)
 - [GetXRPRippleTransactionDetailsByTransactionIDResponseItemReceive](docs/GetXRPRippleTransactionDetailsByTransactionIDResponseItemReceive.md)
 - [GetXRPRippleTransactionDetailsByTransactionIDResponseItemRecipients](docs/GetXRPRippleTransactionDetailsByTransactionIDResponseItemRecipients.md)
 - [GetXRPRippleTransactionDetailsByTransactionIDResponseItemSenders](docs/GetXRPRippleTransactionDetailsByTransactionIDResponseItemSenders.md)
 - [GetXRPRippleTransactionDetailsByTransactionIDResponseItemValue](docs/GetXRPRippleTransactionDetailsByTransactionIDResponseItemValue.md)
 - [InsufficientCredits](docs/InsufficientCredits.md)
 - [InsufficientCreditsError](docs/InsufficientCreditsError.md)
 - [InvalidApiKey](docs/InvalidApiKey.md)
 - [InvalidApiKeyError](docs/InvalidApiKeyError.md)
 - [InvalidBlockchain](docs/InvalidBlockchain.md)
 - [InvalidBlockchainError](docs/InvalidBlockchainError.md)
 - [InvalidData](docs/InvalidData.md)
 - [InvalidDataError](docs/InvalidDataError.md)
 - [InvalidNetwork](docs/InvalidNetwork.md)
 - [InvalidNetworkError](docs/InvalidNetworkError.md)
 - [InvalidPagination](docs/InvalidPagination.md)
 - [InvalidPaginationError](docs/InvalidPaginationError.md)
 - [InvalidRequestBodyStructure](docs/InvalidRequestBodyStructure.md)
 - [InvalidRequestBodyStructureError](docs/InvalidRequestBodyStructureError.md)
 - [InvalidXpub](docs/InvalidXpub.md)
 - [InvalidXpubError](docs/InvalidXpubError.md)
 - [LimitGreaterThanAllowed](docs/LimitGreaterThanAllowed.md)
 - [LimitGreaterThanAllowedError](docs/LimitGreaterThanAllowedError.md)
 - [ListAssetsDetailsResponse](docs/ListAssetsDetailsResponse.md)
 - [ListAssetsDetailsResponseData](docs/ListAssetsDetailsResponseData.md)
 - [ListAssetsDetailsResponseItem](docs/ListAssetsDetailsResponseItem.md)
 - [ListAssetsDetailsResponseItemAssetLogo](docs/ListAssetsDetailsResponseItemAssetLogo.md)
 - [ListAssetsDetailsResponseItemLatestRate](docs/ListAssetsDetailsResponseItemLatestRate.md)
 - [ListAssetsDetailsResponseItemSpecificData](docs/ListAssetsDetailsResponseItemSpecificData.md)
 - [ListAssetsDetailsResponseItemSpecificDataCryptoTypeData](docs/ListAssetsDetailsResponseItemSpecificDataCryptoTypeData.md)
 - [ListBlockchainEventsSubscriptionsResponse](docs/ListBlockchainEventsSubscriptionsResponse.md)
 - [ListBlockchainEventsSubscriptionsResponseData](docs/ListBlockchainEventsSubscriptionsResponseData.md)
 - [ListBlockchainEventsSubscriptionsResponseItem](docs/ListBlockchainEventsSubscriptionsResponseItem.md)
 - [ListCoinsForwardingAutomationsResponse](docs/ListCoinsForwardingAutomationsResponse.md)
 - [ListCoinsForwardingAutomationsResponseData](docs/ListCoinsForwardingAutomationsResponseData.md)
 - [ListCoinsForwardingAutomationsResponseItem](docs/ListCoinsForwardingAutomationsResponseItem.md)
 - [ListHDWalletxPubYPubZPubTransactionsResponse](docs/ListHDWalletxPubYPubZPubTransactionsResponse.md)
 - [ListHDWalletxPubYPubZPubTransactionsResponseData](docs/ListHDWalletxPubYPubZPubTransactionsResponseData.md)
 - [ListHDWalletxPubYPubZPubTransactionsResponseItem](docs/ListHDWalletxPubYPubZPubTransactionsResponseItem.md)
 - [ListHDWalletxPubYPubZPubTransactionsResponseItemFee](docs/ListHDWalletxPubYPubZPubTransactionsResponseItemFee.md)
 - [ListHDWalletxPubYPubZPubTransactionsResponseItemRecipients](docs/ListHDWalletxPubYPubZPubTransactionsResponseItemRecipients.md)
 - [ListHDWalletxPubYPubZPubTransactionsResponseItemSenders](docs/ListHDWalletxPubYPubZPubTransactionsResponseItemSenders.md)
 - [ListOmniTokensByAddressResponse](docs/ListOmniTokensByAddressResponse.md)
 - [ListOmniTokensByAddressResponseData](docs/ListOmniTokensByAddressResponseData.md)
 - [ListOmniTokensByAddressResponseItem](docs/ListOmniTokensByAddressResponseItem.md)
 - [ListOmniTransactionsByAddressResponse](docs/ListOmniTransactionsByAddressResponse.md)
 - [ListOmniTransactionsByAddressResponseData](docs/ListOmniTransactionsByAddressResponseData.md)
 - [ListOmniTransactionsByAddressResponseItem](docs/ListOmniTransactionsByAddressResponseItem.md)
 - [ListOmniTransactionsByAddressResponseItemFee](docs/ListOmniTransactionsByAddressResponseItemFee.md)
 - [ListOmniTransactionsByAddressResponseItemRecipients](docs/ListOmniTransactionsByAddressResponseItemRecipients.md)
 - [ListOmniTransactionsByAddressResponseItemSenders](docs/ListOmniTransactionsByAddressResponseItemSenders.md)
 - [ListOmniTransactionsByBlockHashResponse](docs/ListOmniTransactionsByBlockHashResponse.md)
 - [ListOmniTransactionsByBlockHashResponseData](docs/ListOmniTransactionsByBlockHashResponseData.md)
 - [ListOmniTransactionsByBlockHashResponseItem](docs/ListOmniTransactionsByBlockHashResponseItem.md)
 - [ListOmniTransactionsByBlockHashResponseItemFee](docs/ListOmniTransactionsByBlockHashResponseItemFee.md)
 - [ListOmniTransactionsByBlockHeightResponse](docs/ListOmniTransactionsByBlockHeightResponse.md)
 - [ListOmniTransactionsByBlockHeightResponseData](docs/ListOmniTransactionsByBlockHeightResponseData.md)
 - [ListOmniTransactionsByBlockHeightResponseItem](docs/ListOmniTransactionsByBlockHeightResponseItem.md)
 - [ListOmniTransactionsByBlockHeightResponseItemFee](docs/ListOmniTransactionsByBlockHeightResponseItemFee.md)
 - [ListOmniTransactionsByBlockHeightResponseItemRecipients](docs/ListOmniTransactionsByBlockHeightResponseItemRecipients.md)
 - [ListOmniTransactionsByBlockHeightResponseItemSenders](docs/ListOmniTransactionsByBlockHeightResponseItemSenders.md)
 - [ListSupportedAssetsResponse](docs/ListSupportedAssetsResponse.md)
 - [ListSupportedAssetsResponseData](docs/ListSupportedAssetsResponseData.md)
 - [ListSupportedAssetsResponseItem](docs/ListSupportedAssetsResponseItem.md)
 - [ListTokensByAddressResponse](docs/ListTokensByAddressResponse.md)
 - [ListTokensByAddressResponseData](docs/ListTokensByAddressResponseData.md)
 - [ListTokensByAddressResponseItem](docs/ListTokensByAddressResponseItem.md)
 - [ListTokensForwardingAutomationsResponse](docs/ListTokensForwardingAutomationsResponse.md)
 - [ListTokensForwardingAutomationsResponseData](docs/ListTokensForwardingAutomationsResponseData.md)
 - [ListTokensForwardingAutomationsResponseItem](docs/ListTokensForwardingAutomationsResponseItem.md)
 - [ListTokensForwardingAutomationsResponseItemTokenData](docs/ListTokensForwardingAutomationsResponseItemTokenData.md)
 - [ListTokensForwardingAutomationsResponseItemTokenDataBitcoinOmniToken](docs/ListTokensForwardingAutomationsResponseItemTokenDataBitcoinOmniToken.md)
 - [ListTokensForwardingAutomationsResponseItemTokenDataEthereumToken](docs/ListTokensForwardingAutomationsResponseItemTokenDataEthereumToken.md)
 - [ListTokensTransfersByAddressResponse](docs/ListTokensTransfersByAddressResponse.md)
 - [ListTokensTransfersByAddressResponseData](docs/ListTokensTransfersByAddressResponseData.md)
 - [ListTokensTransfersByAddressResponseItem](docs/ListTokensTransfersByAddressResponseItem.md)
 - [ListTokensTransfersByTransactionHashResponse](docs/ListTokensTransfersByTransactionHashResponse.md)
 - [ListTokensTransfersByTransactionHashResponseData](docs/ListTokensTransfersByTransactionHashResponseData.md)
 - [ListTokensTransfersByTransactionHashResponseItem](docs/ListTokensTransfersByTransactionHashResponseItem.md)
 - [ListTransactionsByAddressResponse](docs/ListTransactionsByAddressResponse.md)
 - [ListTransactionsByAddressResponseData](docs/ListTransactionsByAddressResponseData.md)
 - [ListTransactionsByAddressResponseItem](docs/ListTransactionsByAddressResponseItem.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecific](docs/ListTransactionsByAddressResponseItemBlockchainSpecific.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificBitcoin](docs/ListTransactionsByAddressResponseItemBlockchainSpecificBitcoin.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificBitcoinCash](docs/ListTransactionsByAddressResponseItemBlockchainSpecificBitcoinCash.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificBitcoinCashVin](docs/ListTransactionsByAddressResponseItemBlockchainSpecificBitcoinCashVin.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificBitcoinScriptPubKey](docs/ListTransactionsByAddressResponseItemBlockchainSpecificBitcoinScriptPubKey.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificBitcoinVin](docs/ListTransactionsByAddressResponseItemBlockchainSpecificBitcoinVin.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificBitcoinVout](docs/ListTransactionsByAddressResponseItemBlockchainSpecificBitcoinVout.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificDash](docs/ListTransactionsByAddressResponseItemBlockchainSpecificDash.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificDashScriptPubKey](docs/ListTransactionsByAddressResponseItemBlockchainSpecificDashScriptPubKey.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificDashScriptSig](docs/ListTransactionsByAddressResponseItemBlockchainSpecificDashScriptSig.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificDashVin](docs/ListTransactionsByAddressResponseItemBlockchainSpecificDashVin.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificDashVout](docs/ListTransactionsByAddressResponseItemBlockchainSpecificDashVout.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificDogecoin](docs/ListTransactionsByAddressResponseItemBlockchainSpecificDogecoin.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificDogecoinScriptSig](docs/ListTransactionsByAddressResponseItemBlockchainSpecificDogecoinScriptSig.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificDogecoinVin](docs/ListTransactionsByAddressResponseItemBlockchainSpecificDogecoinVin.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificEthereum](docs/ListTransactionsByAddressResponseItemBlockchainSpecificEthereum.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificEthereumClassic](docs/ListTransactionsByAddressResponseItemBlockchainSpecificEthereumClassic.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificEthereumClassicGasPrice](docs/ListTransactionsByAddressResponseItemBlockchainSpecificEthereumClassicGasPrice.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificEthereumGasPrice](docs/ListTransactionsByAddressResponseItemBlockchainSpecificEthereumGasPrice.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificLitecoin](docs/ListTransactionsByAddressResponseItemBlockchainSpecificLitecoin.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificLitecoinScriptSig](docs/ListTransactionsByAddressResponseItemBlockchainSpecificLitecoinScriptSig.md)
 - [ListTransactionsByAddressResponseItemBlockchainSpecificLitecoinVin](docs/ListTransactionsByAddressResponseItemBlockchainSpecificLitecoinVin.md)
 - [ListTransactionsByBlockHashResponse](docs/ListTransactionsByBlockHashResponse.md)
 - [ListTransactionsByBlockHashResponseData](docs/ListTransactionsByBlockHashResponseData.md)
 - [ListTransactionsByBlockHashResponseItem](docs/ListTransactionsByBlockHashResponseItem.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecific](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecific.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoin](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoin.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoinCash](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoinCash.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoinCashScriptPubKey](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoinCashScriptPubKey.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoinCashVin](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoinCashVin.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoinCashVout](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoinCashVout.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoinVin](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificBitcoinVin.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificDash](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificDash.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificDashScriptPubKey](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificDashScriptPubKey.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificDashScriptSig](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificDashScriptSig.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificDashVin](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificDashVin.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificDashVout](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificDashVout.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificDogecoin](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificDogecoin.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificDogecoinScriptPubKey](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificDogecoinScriptPubKey.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificDogecoinVin](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificDogecoinVin.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificDogecoinVout](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificDogecoinVout.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificEthereum](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificEthereum.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificEthereumClassic](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificEthereumClassic.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificEthereumGasPrice](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificEthereumGasPrice.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificLitecoin](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificLitecoin.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificLitecoinScriptPubKey](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificLitecoinScriptPubKey.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificLitecoinVin](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificLitecoinVin.md)
 - [ListTransactionsByBlockHashResponseItemBlockchainSpecificLitecoinVout](docs/ListTransactionsByBlockHashResponseItemBlockchainSpecificLitecoinVout.md)
 - [ListTransactionsByBlockHashResponseItemFee](docs/ListTransactionsByBlockHashResponseItemFee.md)
 - [ListTransactionsByBlockHashResponseItemRecipients](docs/ListTransactionsByBlockHashResponseItemRecipients.md)
 - [ListTransactionsByBlockHashResponseItemSenders](docs/ListTransactionsByBlockHashResponseItemSenders.md)
 - [ListTransactionsByBlockHeightResponse](docs/ListTransactionsByBlockHeightResponse.md)
 - [ListTransactionsByBlockHeightResponseData](docs/ListTransactionsByBlockHeightResponseData.md)
 - [ListTransactionsByBlockHeightResponseItem](docs/ListTransactionsByBlockHeightResponseItem.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecific](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecific.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificBitcoin](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificBitcoin.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificBitcoinCash](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificBitcoinCash.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificBitcoinScriptPubKey](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificBitcoinScriptPubKey.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificBitcoinVout](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificBitcoinVout.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificDash](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificDash.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificDashScriptPubKey](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificDashScriptPubKey.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificDashScriptSig](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificDashScriptSig.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificDashVin](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificDashVin.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificDashVout](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificDashVout.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificDogecoin](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificDogecoin.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificDogecoinVin](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificDogecoinVin.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificEthereum](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificEthereum.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificEthereumClassic](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificEthereumClassic.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificEthereumClassicGasPrice](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificEthereumClassicGasPrice.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificLitecoin](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificLitecoin.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificLitecoinScriptPubKey](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificLitecoinScriptPubKey.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificLitecoinScriptSig](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificLitecoinScriptSig.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificLitecoinVin](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificLitecoinVin.md)
 - [ListTransactionsByBlockHeightResponseItemBlockchainSpecificLitecoinVout](docs/ListTransactionsByBlockHeightResponseItemBlockchainSpecificLitecoinVout.md)
 - [ListTransactionsByBlockHeightResponseItemFee](docs/ListTransactionsByBlockHeightResponseItemFee.md)
 - [ListUnconfirmedOmniTransactionsByAddressResponse](docs/ListUnconfirmedOmniTransactionsByAddressResponse.md)
 - [ListUnconfirmedOmniTransactionsByAddressResponseData](docs/ListUnconfirmedOmniTransactionsByAddressResponseData.md)
 - [ListUnconfirmedOmniTransactionsByAddressResponseItem](docs/ListUnconfirmedOmniTransactionsByAddressResponseItem.md)
 - [ListUnconfirmedOmniTransactionsByAddressResponseItemFee](docs/ListUnconfirmedOmniTransactionsByAddressResponseItemFee.md)
 - [ListUnconfirmedOmniTransactionsByAddressResponseItemSenders](docs/ListUnconfirmedOmniTransactionsByAddressResponseItemSenders.md)
 - [ListUnconfirmedOmniTransactionsByPropertyIDResponse](docs/ListUnconfirmedOmniTransactionsByPropertyIDResponse.md)
 - [ListUnconfirmedOmniTransactionsByPropertyIDResponseData](docs/ListUnconfirmedOmniTransactionsByPropertyIDResponseData.md)
 - [ListUnconfirmedOmniTransactionsByPropertyIDResponseItem](docs/ListUnconfirmedOmniTransactionsByPropertyIDResponseItem.md)
 - [ListXRPRippleTransactionsByAddressResponse](docs/ListXRPRippleTransactionsByAddressResponse.md)
 - [ListXRPRippleTransactionsByAddressResponseData](docs/ListXRPRippleTransactionsByAddressResponseData.md)
 - [ListXRPRippleTransactionsByAddressResponseItem](docs/ListXRPRippleTransactionsByAddressResponseItem.md)
 - [ListXRPRippleTransactionsByAddressResponseItemFee](docs/ListXRPRippleTransactionsByAddressResponseItemFee.md)
 - [ListXRPRippleTransactionsByAddressResponseItemOffer](docs/ListXRPRippleTransactionsByAddressResponseItemOffer.md)
 - [ListXRPRippleTransactionsByAddressResponseItemReceive](docs/ListXRPRippleTransactionsByAddressResponseItemReceive.md)
 - [ListXRPRippleTransactionsByAddressResponseItemValue](docs/ListXRPRippleTransactionsByAddressResponseItemValue.md)
 - [ListXRPRippleTransactionsByBlockHashResponse](docs/ListXRPRippleTransactionsByBlockHashResponse.md)
 - [ListXRPRippleTransactionsByBlockHashResponseData](docs/ListXRPRippleTransactionsByBlockHashResponseData.md)
 - [ListXRPRippleTransactionsByBlockHashResponseItem](docs/ListXRPRippleTransactionsByBlockHashResponseItem.md)
 - [ListXRPRippleTransactionsByBlockHashResponseItemFee](docs/ListXRPRippleTransactionsByBlockHashResponseItemFee.md)
 - [ListXRPRippleTransactionsByBlockHashResponseItemOffer](docs/ListXRPRippleTransactionsByBlockHashResponseItemOffer.md)
 - [ListXRPRippleTransactionsByBlockHashResponseItemReceive](docs/ListXRPRippleTransactionsByBlockHashResponseItemReceive.md)
 - [ListXRPRippleTransactionsByBlockHashResponseItemRecipients](docs/ListXRPRippleTransactionsByBlockHashResponseItemRecipients.md)
 - [ListXRPRippleTransactionsByBlockHashResponseItemSenders](docs/ListXRPRippleTransactionsByBlockHashResponseItemSenders.md)
 - [ListXRPRippleTransactionsByBlockHashResponseItemValue](docs/ListXRPRippleTransactionsByBlockHashResponseItemValue.md)
 - [MinedTransactionRequestBody](docs/MinedTransactionRequestBody.md)
 - [MinedTransactionRequestBodyData](docs/MinedTransactionRequestBodyData.md)
 - [MinedTransactionRequestBodyDataItem](docs/MinedTransactionRequestBodyDataItem.md)
 - [MinedTransactionResponse](docs/MinedTransactionResponse.md)
 - [MinedTransactionResponseData](docs/MinedTransactionResponseData.md)
 - [MinedTransactionResponseItem](docs/MinedTransactionResponseItem.md)
 - [MissingApiKey](docs/MissingApiKey.md)
 - [MissingApiKeyError](docs/MissingApiKeyError.md)
 - [NewBlockRequestBody](docs/NewBlockRequestBody.md)
 - [NewBlockRequestBodyData](docs/NewBlockRequestBodyData.md)
 - [NewBlockRequestBodyDataItem](docs/NewBlockRequestBodyDataItem.md)
 - [NewBlockResponse](docs/NewBlockResponse.md)
 - [NewBlockResponseData](docs/NewBlockResponseData.md)
 - [NewBlockResponseItem](docs/NewBlockResponseItem.md)
 - [NewConfirmedCoinsTransactionsAndEachConfirmationRequestBody](docs/NewConfirmedCoinsTransactionsAndEachConfirmationRequestBody.md)
 - [NewConfirmedCoinsTransactionsAndEachConfirmationRequestBodyData](docs/NewConfirmedCoinsTransactionsAndEachConfirmationRequestBodyData.md)
 - [NewConfirmedCoinsTransactionsAndEachConfirmationRequestBodyDataItem](docs/NewConfirmedCoinsTransactionsAndEachConfirmationRequestBodyDataItem.md)
 - [NewConfirmedCoinsTransactionsAndEachConfirmationResponse](docs/NewConfirmedCoinsTransactionsAndEachConfirmationResponse.md)
 - [NewConfirmedCoinsTransactionsAndEachConfirmationResponseData](docs/NewConfirmedCoinsTransactionsAndEachConfirmationResponseData.md)
 - [NewConfirmedCoinsTransactionsAndEachConfirmationResponseItem](docs/NewConfirmedCoinsTransactionsAndEachConfirmationResponseItem.md)
 - [NewConfirmedCoinsTransactionsRequestBody](docs/NewConfirmedCoinsTransactionsRequestBody.md)
 - [NewConfirmedCoinsTransactionsRequestBodyData](docs/NewConfirmedCoinsTransactionsRequestBodyData.md)
 - [NewConfirmedCoinsTransactionsRequestBodyDataItem](docs/NewConfirmedCoinsTransactionsRequestBodyDataItem.md)
 - [NewConfirmedCoinsTransactionsResponse](docs/NewConfirmedCoinsTransactionsResponse.md)
 - [NewConfirmedCoinsTransactionsResponseData](docs/NewConfirmedCoinsTransactionsResponseData.md)
 - [NewConfirmedCoinsTransactionsResponseItem](docs/NewConfirmedCoinsTransactionsResponseItem.md)
 - [NewConfirmedTokensTransactionsAndEachConfirmationRequestBody](docs/NewConfirmedTokensTransactionsAndEachConfirmationRequestBody.md)
 - [NewConfirmedTokensTransactionsAndEachConfirmationRequestBodyData](docs/NewConfirmedTokensTransactionsAndEachConfirmationRequestBodyData.md)
 - [NewConfirmedTokensTransactionsAndEachConfirmationRequestBodyDataItem](docs/NewConfirmedTokensTransactionsAndEachConfirmationRequestBodyDataItem.md)
 - [NewConfirmedTokensTransactionsAndEachConfirmationResponse](docs/NewConfirmedTokensTransactionsAndEachConfirmationResponse.md)
 - [NewConfirmedTokensTransactionsAndEachConfirmationResponseData](docs/NewConfirmedTokensTransactionsAndEachConfirmationResponseData.md)
 - [NewConfirmedTokensTransactionsAndEachConfirmationResponseItem](docs/NewConfirmedTokensTransactionsAndEachConfirmationResponseItem.md)
 - [NewConfirmedTokensTransactionsRequestBody](docs/NewConfirmedTokensTransactionsRequestBody.md)
 - [NewConfirmedTokensTransactionsResponse](docs/NewConfirmedTokensTransactionsResponse.md)
 - [NewConfirmedTokensTransactionsResponseData](docs/NewConfirmedTokensTransactionsResponseData.md)
 - [NewConfirmedTokensTransactionsResponseItem](docs/NewConfirmedTokensTransactionsResponseItem.md)
 - [NewUnconfirmedCoinsTransactionsRequestBody](docs/NewUnconfirmedCoinsTransactionsRequestBody.md)
 - [NewUnconfirmedCoinsTransactionsRequestBodyData](docs/NewUnconfirmedCoinsTransactionsRequestBodyData.md)
 - [NewUnconfirmedCoinsTransactionsRequestBodyDataItem](docs/NewUnconfirmedCoinsTransactionsRequestBodyDataItem.md)
 - [NewUnconfirmedCoinsTransactionsResponse](docs/NewUnconfirmedCoinsTransactionsResponse.md)
 - [NewUnconfirmedCoinsTransactionsResponseData](docs/NewUnconfirmedCoinsTransactionsResponseData.md)
 - [NewUnconfirmedCoinsTransactionsResponseItem](docs/NewUnconfirmedCoinsTransactionsResponseItem.md)
 - [NewUnconfirmedTokensTransactionsRequestBody](docs/NewUnconfirmedTokensTransactionsRequestBody.md)
 - [NewUnconfirmedTokensTransactionsRequestBodyData](docs/NewUnconfirmedTokensTransactionsRequestBodyData.md)
 - [NewUnconfirmedTokensTransactionsRequestBodyDataItem](docs/NewUnconfirmedTokensTransactionsRequestBodyDataItem.md)
 - [NewUnconfirmedTokensTransactionsResponse](docs/NewUnconfirmedTokensTransactionsResponse.md)
 - [NewUnconfirmedTokensTransactionsResponseData](docs/NewUnconfirmedTokensTransactionsResponseData.md)
 - [NewUnconfirmedTokensTransactionsResponseItem](docs/NewUnconfirmedTokensTransactionsResponseItem.md)
 - [RequestLimitReached](docs/RequestLimitReached.md)
 - [RequestLimitReachedError](docs/RequestLimitReachedError.md)
 - [ResourceNotFound](docs/ResourceNotFound.md)
 - [ResourceNotFoundError](docs/ResourceNotFoundError.md)
 - [SyncHDWalletxPubYPubZPubRequestBody](docs/SyncHDWalletxPubYPubZPubRequestBody.md)
 - [SyncHDWalletxPubYPubZPubRequestBodyData](docs/SyncHDWalletxPubYPubZPubRequestBodyData.md)
 - [SyncHDWalletxPubYPubZPubRequestBodyDataItem](docs/SyncHDWalletxPubYPubZPubRequestBodyDataItem.md)
 - [SyncHDWalletxPubYPubZPubResponse](docs/SyncHDWalletxPubYPubZPubResponse.md)
 - [SyncHDWalletxPubYPubZPubResponseData](docs/SyncHDWalletxPubYPubZPubResponseData.md)
 - [SyncHDWalletxPubYPubZPubResponseItem](docs/SyncHDWalletxPubYPubZPubResponseItem.md)
 - [TokensForwardingAutomationsLimitReached](docs/TokensForwardingAutomationsLimitReached.md)
 - [TokensForwardingAutomationsLimitReachedError](docs/TokensForwardingAutomationsLimitReachedError.md)
 - [TokensForwardingFail](docs/TokensForwardingFail.md)
 - [TokensForwardingFailData](docs/TokensForwardingFailData.md)
 - [TokensForwardingFailDataItem](docs/TokensForwardingFailDataItem.md)
 - [TokensForwardingSuccess](docs/TokensForwardingSuccess.md)
 - [TokensForwardingSuccessData](docs/TokensForwardingSuccessData.md)
 - [TokensForwardingSuccessDataItem](docs/TokensForwardingSuccessDataItem.md)
 - [TokensForwardingSuccessEthereumerc20token](docs/TokensForwardingSuccessEthereumerc20token.md)
 - [TokensForwardingSuccessEthereumerc721token](docs/TokensForwardingSuccessEthereumerc721token.md)
 - [TokensForwardingSuccessOmnilayertoken](docs/TokensForwardingSuccessOmnilayertoken.md)
 - [TokensForwardingSuccessToken](docs/TokensForwardingSuccessToken.md)
 - [TransactionMined](docs/TransactionMined.md)
 - [TransactionMinedData](docs/TransactionMinedData.md)
 - [TransactionMinedDataItem](docs/TransactionMinedDataItem.md)
 - [TransactionMinedDataItemMinedInBlock](docs/TransactionMinedDataItemMinedInBlock.md)
 - [UnexpectedServerError](docs/UnexpectedServerError.md)
 - [UnexpectedServerErrorError](docs/UnexpectedServerErrorError.md)
 - [UnsupportedMediaType](docs/UnsupportedMediaType.md)
 - [UnsupportedMediaTypeError](docs/UnsupportedMediaTypeError.md)
 - [UriNotFound](docs/UriNotFound.md)
 - [UriNotFoundError](docs/UriNotFoundError.md)
 - [ValidateAddressRequestBody](docs/ValidateAddressRequestBody.md)
 - [ValidateAddressRequestBodyData](docs/ValidateAddressRequestBodyData.md)
 - [ValidateAddressRequestBodyDataItem](docs/ValidateAddressRequestBodyDataItem.md)
 - [ValidateAddressResponse](docs/ValidateAddressResponse.md)
 - [ValidateAddressResponseData](docs/ValidateAddressResponseData.md)
 - [ValidateAddressResponseItem](docs/ValidateAddressResponseItem.md)
 - [XpubNotSynced](docs/XpubNotSynced.md)
 - [XpubNotSyncedError](docs/XpubNotSyncedError.md)
 - [XpubSyncInProgress](docs/XpubSyncInProgress.md)
 - [XpubSyncInProgressError](docs/XpubSyncInProgressError.md)


## Documentation For Authorization


## ApiKey

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header


## Author

developers@cryptoapis.io


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in cryptoapis.apis and cryptoapis.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from cryptoapis.api.default_api import DefaultApi`
- `from cryptoapis.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import cryptoapis
from cryptoapis.apis import *
from cryptoapis.models import *
```

